=== modified file 'bzrlib/decorators.py'
--- bzrlib/decorators.py	2006-01-12 08:37:10 +0000
+++ bzrlib/decorators.py	2006-01-13 06:38:56 +0000
@@ -34,6 +34,8 @@
             return unbound(self, *args, **kwargs)
         finally:
             self.unlock()
+    decorated.__doc__ = unbound.__doc__
+    decorated.__name__ = unbound.__name__
     return decorated
 
 
@@ -45,5 +47,7 @@
             return unbound(self, *args, **kwargs)
         finally:
             self.unlock()
+    decorated.__doc__ = unbound.__doc__
+    decorated.__name__ = unbound.__name__
     return decorated
 

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-01-12 08:48:59 +0000
+++ bzrlib/tests/__init__.py	2006-01-13 06:38:56 +0000
@@ -692,6 +692,7 @@
                    'bzrlib.tests.test_config',
                    'bzrlib.tests.test_conflicts',
                    'bzrlib.tests.test_diff',
+                   'bzrlib.tests.test_decorators',
                    'bzrlib.tests.test_fetch',
                    'bzrlib.tests.test_gpg',
                    'bzrlib.tests.test_graph',

=== added file 'bzrlib/tests/test_decorators.py'
--- bzrlib/tests/test_decorators.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/test_decorators.py	2006-01-13 06:38:56 +0000
@@ -0,0 +1,44 @@
+# Copyright (C) 2006 Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Tests for decorator functions"""
+
+from bzrlib.decorators import needs_read_lock
+from bzrlib.tests import TestCase
+
+
+class DecoratorSample(object):
+    """Sample class that uses decorators.
+
+    This doesn't actually work because the class doesn't have the 
+    requiste lock_read()/unlock() methods.
+    """
+
+    @needs_read_lock
+    def frob(self):
+        """Frob the sample object"""
+
+
+class TestDecoratorDocs(TestCase):
+    """Test method decorators"""
+
+    def test_read_lock_passthrough(self):
+        """@needs_read_lock exposes underlying name and doc."""
+        sam = DecoratorSample()
+        self.assertEqual(sam.frob.__name__, 'frob')
+        self.assertEqual(sam.frob.__doc__, 
+                'Frob the sample object')

